docs.rs failed to build sim-lib-topology-0.1.5
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: sim-lib-topology-0.1.4

sim-lib-topology

Data-driven topology engine.

Package Metadata

  • Manifest: crates/sim-lib-topology/Cargo.toml
  • Publish: true
  • Targets: custom-build, lib

Crate Documentation

Data-driven topology engine.