pub struct PortRef {
pub node: NodeId,
pub port: Symbol,
}Expand description
Reference to a named port on a node.
Fields
node: NodeIdThe node that owns the referenced port.
port: SymbolThe referenced port name.
Implementations
Sourceimpl PortRef
impl PortRef
Sourcepub fn new(node: impl Into<NodeId>, port: Symbol) -> Self
pub fn new(node: impl Into<NodeId>, port: Symbol) -> Self
Creates a port reference from an explicit node and port symbol.
Sourcepub fn named(node: impl Into<NodeId>, port: impl Into<String>) -> Self
pub fn named(node: impl Into<NodeId>, port: impl Into<String>) -> Self
Creates a port reference from an unqualified port name.