Module parse

Module parse 

Parsing of canonical expression and list forms into topology graph data.

Functions

graph_from_value
Parses a runtime value into a Graph; alias for parse_graph.
parse_graph
Parses a runtime value into canonical topology graph data.