pub enum PatchOp {
AddNode(Node),
RemoveNode(NodeId),
ReplaceNode {
id: NodeId,
node: Node,
},
AddEdge {
edge: Edge,
explicit_id: bool,
},
RemoveEdge {
from: PortRef,
to: PortRef,
},
ReplaceEdge {
from: PortRef,
to: PortRef,
edge: Edge,
explicit_id: bool,
},
AddCell(Cell),
SetBudget(Budget),
SetScheduler(Scheduler),
SetMetadata {
key: Symbol,
value: Expr,
},
}Expand description
One topology patch operation.
Variants
AddNode(Node)
Add a graph node.
RemoveNode(NodeId)
Remove a graph node by id.
ReplaceNode
Replace an existing graph node.
AddEdge
Add a graph edge.
Fields
RemoveEdge
Remove an edge identified by source and destination endpoints.
ReplaceEdge
Replace an edge identified by source and destination endpoints.
Fields
AddCell(Cell)
Add a graph state cell.
SetBudget(Budget)
Replace graph budget settings.
SetScheduler(Scheduler)
Replace graph scheduler settings.
SetMetadata
Set or insert one graph metadata entry.