Parsing of canonical expression and list forms into topology graph data.
Functions
- graph_
from_ value - Parses a runtime value into a
Graph; alias forparse_graph. - parse_
graph - Parses a runtime value into canonical topology graph data.