PatchOp

Enum PatchOp 

pub enum PatchOp {
    AddNode(Node),
    RemoveNode(NodeId),
    ReplaceNode {
        id: NodeId,
        node: Node,
    },
    AddEdge {
        edge: Edge,
        explicit_id: bool,
    },
    RemoveEdge {
        from: PortRef,
        to: PortRef,
    },
    ReplaceEdge {
        from: PortRef,
        to: PortRef,
        edge: Edge,
        explicit_id: bool,
    },
    AddCell(Cell),
    SetBudget(Budget),
    SetScheduler(Scheduler),
    SetMetadata {
        key: Symbol,
        value: Expr,
    },
}
One topology patch operation.

Variants



AddNode(Node)

Add a graph node.



RemoveNode(NodeId)

Remove a graph node by id.



ReplaceNode

Replace an existing graph node.

Fields

id: NodeId

The node id to replace.

node: Node

The replacement node.



AddEdge

Add a graph edge.

Fields

edge: Edge

The edge to add.

explicit_id: bool

Whether the edge id was given explicitly rather than assigned.



RemoveEdge

Remove an edge identified by source and destination endpoints.

Fields

from: PortRef

The source endpoint.

to: PortRef

The destination endpoint.



ReplaceEdge

Replace an edge identified by source and destination endpoints.

Fields

from: PortRef

The source endpoint of the edge to replace.

to: PortRef

The destination endpoint of the edge to replace.

edge: Edge

The replacement edge.

explicit_id: bool

Whether the edge id was given explicitly rather than assigned.



AddCell(Cell)

Add a graph state cell.



SetBudget(Budget)

Replace graph budget settings.



SetScheduler(Scheduler)

Replace graph scheduler settings.



SetMetadata

Set or insert one graph metadata entry.

Fields

key: Symbol

The metadata key.

value: Expr

The metadata value.